@@ -6,7 +6,6 @@ import re
 
 import numpy as np
 import pandas as pd
-from itertools import chain
 
 import plotly.graph_objects as go
 import plotly.subplots
@@ -14,7 +13,7 @@ import plotly.express as px
 
 import holoviews as hv
 from holoviews.operation.datashader import dynspread, rasterize, shade
-from bokeh.models import BoxZoomTool, WheelZoomTool, ResetTool, SaveTool
+from bokeh.io import export_svgs
 
 import alphaviz.preprocessing
 import alphaviz.utils
@@ -28,7 +27,7 @@ def plot_sequence_coverage(
     colorscale_sequential: str,
     regex: str,
     prot_id: str = ""
-)-> go.Figure:
+) -> go.Figure:
     """Create a protein sequence coverage plot.
 
     Parameters
@@ -128,15 +127,15 @@ def plot_sequence_coverage(
         ),
         yaxis=dict(
             tickfont_size=1,
-            showticklabels = False,
-            nticks = 0,
+            showticklabels=False,
+            nticks=0,
             visible=False
         ),
         barmode='overlay',
-        bargap=0, # gap between bars of adjacent location coordinates.
-        bargroupgap=0, # gap between bars of the same location coordinate.
+        bargap=0,  # gap between bars of adjacent location coordinates.
+        bargroupgap=0,  # gap between bars of the same location coordinate.
         hovermode="x",
-        template = "plotly_white", #"plotly", "plotly_white", "plotly_dark", "ggplot2", "seaborn", "simple_white"
+        template="plotly_white",  # "plotly", "plotly_white", "plotly_dark", "ggplot2", "seaborn", "simple_white"
         # width=1000,
         height=200
     )
@@ -148,8 +147,9 @@ def plot_sequence_coverage(
 
 
 def plot_chrom(
-    data #alphatims.bruker.TimsTOF object
-)-> go.Figure:
+    data,  # alphatims.bruker.TimsTOF object
+    colorscale_qualitative: str,
+) -> go.Figure:
     """Create a plot showing 4 chromatogram types: total ion chromatogram (TIC) and base peak chromatogram (BPC) for MS1 and MS2 raw data.
 
     Parameters
@@ -174,7 +174,7 @@ def plot_chrom(
     total_ion_col = ['RT', 'SummedIntensities']
     base_peak_col = ['RT', 'MaxIntensity']
 
-    for chrom_type in ['Total Ion Chromatogram - MS1', 'Base Peak Chromatogram - MS1', 'Total Ion Chromatogram - MS2','Base Peak Chromatogram - MS2']:
+    for i, chrom_type in enumerate(['Total Ion Chromatogram - MS1', 'Base Peak Chromatogram - MS1', 'Total Ion Chromatogram - MS2', 'Base Peak Chromatogram - MS2']):
         if chrom_type == 'Total Ion Chromatogram - MS1':
             data = chrom_ms1[total_ion_col]
         elif chrom_type == 'Total Ion Chromatogram - MS2':
@@ -189,12 +189,13 @@ def plot_chrom(
                 y=data.iloc[:, 1],
                 name=chrom_type,
                 hovertemplate='<b>RT:</b> %{x};<br><b>Intensity:</b> %{y}.',
+                marker=dict(color=getattr(px.colors.qualitative, colorscale_qualitative)[i]),
             )
         )
 
     fig.update_layout(
         title=dict(
-            text=f"Chromatograms",
+            text="Chromatograms",
             font=dict(
                 size=16,
             ),
@@ -247,7 +248,7 @@ def plot_heatmap(
     precursor_size: int = 15,
     colormap: str = 'fire',
     **kwargs
-)-> hv.Scatter:
+) -> hv.Scatter:
     """Create a heatmap for the MS1/MS2 frame that overlaps with the precursor mark at the location where the precursor has been selected for analysis.
 
     Parameters
@@ -300,10 +301,6 @@ def plot_heatmap(
     y_dimension = labels[y_axis_label]
     z_dimension = labels[z_axis_label]
 
-    # def hook(plot, element):
-    #     plot.handles['layout']['xaxis']['gridcolor'] = background_color
-    #     plot.handles['layout']['yaxis']['gridcolor'] = background_color
-
     opts_ms1 = dict(
         width=width,
         height=height,
@@ -311,9 +308,7 @@ def plot_heatmap(
         xlabel=x_axis_label,
         ylabel=y_axis_label,
         bgcolor=background_color,
-        # hooks=[hook],
         hooks=[_change_plot],
-        tools=['save', 'wheel_zoom', 'box_zoom', 'reset'],
         **kwargs
     )
     dmap = hv.DynamicMap(
@@ -352,26 +347,22 @@ def plot_heatmap(
         return fig * precursor
     return fig
 
+
 def _change_plot(plot, element):
     plot.state.toolbar.logo = None
-    plot.state.toolbar.tools = [
-        BoxZoomTool(match_aspect=True),
-        WheelZoomTool(),
-        ResetTool(),
-        SaveTool()
-    ]
 
 
 def plot_line(
-    timstof_data, #alphatims.bruker.TimsTOF object
+    timstof_data,  # alphatims.bruker.TimsTOF object
     selected_indices: np.ndarray,
     x_axis_label: str,
+    colorscale_qualitative: str,
     title: str = "",
     y_axis_label: str = "intensity",
     remove_zeros: bool = False,
     trim: bool = True,
     height: int = 400
-)-> go.Figure:
+) -> go.Figure:
     """Plot an XIC, mobilogram or spectrum as a lineplot.
 
     Parameters
@@ -446,9 +437,10 @@ def plot_line(
             x=x_ticks,
             y=intensities,
             mode='lines',
-            text = [f'{x_axis_label}'.format(i + 1) for i in range(len(x_ticks))],
+            text=[f'{x_axis_label}'.format(i + 1) for i in range(len(x_ticks))],
             hovertemplate='<b>%{text}:</b> %{x};<br><b>Intensity:</b> %{y}.',
-            name=" "
+            name=" ",
+            marker=dict(color=getattr(px.colors.qualitative, colorscale_qualitative)[0])
         )
     )
 
@@ -465,13 +457,13 @@ def plot_line(
         xaxis=dict(
             title=x_axis_label,
             titlefont_size=14,
-            tickmode = 'auto',
+            tickmode='auto',
             tickfont_size=14,
         ),
         yaxis=dict(
             title=y_axis_label,
         ),
-        template = "plotly_white",
+        template="plotly_white",
         height=height,
         hovermode="x"
     )
@@ -482,16 +474,14 @@ def plot_line(
 def plot_mass_spectra(
     data: pd.DataFrame,
     title: str,
-    sequence: str,
-    spectrum_color: str = 'grey',
+    predicted: tuple = (),
     template: str = "plotly_white",
+    spectrum_color: str = 'grey',
     b_ion_color: str = 'red',
     y_ion_color: str = 'blue',
     spectrum_line_width: float = 1.5,
-    font_size_seq: int = 14,
-    font_size_ion: int = 10,
-    height: int = 520
-)-> go.Figure:
+    height: int = 520,
+) -> go.Figure:
     """Plot the mass spectrum with a mass error plot for each ion and annotated peptide sequence as subplots.
 
     Parameters
@@ -500,8 +490,9 @@ def plot_mass_spectra(
         The dataframe containing spectrum information such as 'mz_values', 'intensity_values', 'ions'.
     title : str
         The title of the plot.
-    sequence: str
-        The peptide sequence.
+    predicted : tuple
+        The tuple containing values of the predicted FragmentMz, RelativeIntensity and ions in the form of:
+        (predicted_df.FragmentMz, predicted_df.RelativeIntensity, predicted_df.ions). Default: empty tuple.
     spectrum_color : str
         The color of the mass spectrum. Default is 'grey'.
     b_ion_color : str
@@ -510,12 +501,6 @@ def plot_mass_spectra(
         The color of the y-ions. Default is 'blue'.
     spectrum_line_width: float
         The width of the spectrum peaks. Default is 1.5.
-    font_size_seq: int
-        The font size of the peptide sequence letters. Default is 14.
-    font_size_ion: int
-        The font size of the ion letters. Default is 10.
-    height: int
-        The height of the plot. Default is 520.
 
     Returns
     -------
@@ -525,6 +510,11 @@ def plot_mass_spectra(
     """
     fig = go.Figure()
 
+    if predicted:
+        import sklearn.preprocessing
+        scaled_int = sklearn.preprocessing.MinMaxScaler((0, 100)).fit_transform(data.intensity_values.values.reshape(-1, 1))
+        data['intensity_values'] = scaled_int.reshape(1, -1)[0]
+
     fig.add_trace(
         go.Scatter(
             x=data[data.ions == '-'].mz_values,
@@ -552,7 +542,7 @@ def plot_mass_spectra(
         )
     )
     # b-ions
-    data_b_ions = data[data.ions.str.contains('b')] # Can this include modlosses?
+    data_b_ions = data[data.ions.str.contains('b')]
     fig.add_trace(
         go.Scatter(
             x=data_b_ions.mz_values,
@@ -566,9 +556,54 @@ def plot_mass_spectra(
         )
     )
 
-    # Use the 'shapes' attribute from the layout to draw the vertical lines
+    if predicted:
+        predicted_b_ions_ind = predicted[2][predicted[2].str.contains('b')].index
+        fig.add_trace(
+            go.Scatter(
+                x=predicted[0][predicted_b_ions_ind],
+                y=predicted[1][predicted_b_ions_ind],
+                mode='markers',
+                opacity=0.7,
+                marker=dict(color=b_ion_color, size=1),
+                hovertext=predicted[2],
+                hovertemplate='<b>m/z:</b> %{x};<br><b>Intensity:</b> %{y};<br><b>Ion:</b> %{hovertext}.',
+                name='',
+                showlegend=False
+            )
+        )
+        fig.add_trace(
+            go.Scatter(
+                x=predicted[0][set(predicted[2].index).difference(predicted_b_ions_ind)],
+                y=predicted[1][set(predicted[2].index).difference(predicted_b_ions_ind)],
+                mode='markers',
+                opacity=0.7,
+                marker=dict(color=b_ion_color if 'b' in predicted[2] else y_ion_color, size=1),
+                hovertext=predicted[2],
+                hovertemplate='<b>m/z:</b> %{x};<br><b>Intensity:</b> %{y};<br><b>Ion:</b> %{hovertext}.',
+                name='',
+                showlegend=False
+            )
+        )
+        fig.update_layout(
+            shapes=[
+                dict(
+                    type='line',
+                    xref='x',
+                    yref='y',
+                    x0=predicted[0][i],
+                    y0=0,
+                    opacity=0.7,
+                    x1=predicted[0][i],
+                    y1=predicted[1][i],
+                    line=dict(
+                        color=b_ion_color if 'b' in predicted[2][i] else y_ion_color,
+                        width=spectrum_line_width
+                    )
+                ) for i in range(len(predicted[0]))
+            ],
+        )
+
     fig.update_layout(
-        template=template,
         shapes=[
             dict(
                 type='line',
@@ -579,18 +614,19 @@ def plot_mass_spectra(
                 x1=data.loc[i, 'mz_values'],
                 y1=data.loc[i, 'intensity_values'],
                 line=dict(
-                    color = b_ion_color if 'b' in data.loc[i, 'ions'] else (y_ion_color if 'y' in data.loc[i, 'ions'] else spectrum_color),
+                    color=b_ion_color if 'b' in data.loc[i, 'ions'] else (y_ion_color if 'y' in data.loc[i, 'ions'] else spectrum_color),
                     width=spectrum_line_width
                 )
             ) for i in data.index
-        ],
+        ]
+    )
+
+    fig.update_layout(
+        template=template,
         xaxis=dict(
             visible=True,
             title='m/z, Th',
         ),
-        yaxis=dict(
-            title='Intensity',
-        ),
         legend=dict(
             orientation="h",
             x=1,
@@ -603,8 +639,65 @@ def plot_mass_spectra(
         title=dict(
             text=title,
             yanchor='bottom'
-        )
+        ),
+        yaxis=dict(title='Intensity') if not predicted else dict(
+            title='Relative intensity, %',
+            ticktext=["100", "50", "0", "50", "100"],
+            tickvals=[-100, -50, 0, 50, 100],
+        ),
     )
+    return fig
+
+
+def plot_complex_ms_plot(
+    data: pd.DataFrame,
+    title: str,
+    sequence: str,
+    predicted: tuple = (),
+    spectrum_color: str = 'grey',
+    template: str = "plotly_white",
+    b_ion_color: str = 'red',
+    y_ion_color: str = 'blue',
+    spectrum_line_width: float = 1.5,
+    font_size_seq: int = 14,
+    font_size_ion: int = 10,
+    height: int = 520
+) -> go.Figure:
+    """Plot the mass spectrum with a mass error plot for each ion and annotated peptide sequence as subplots.
+
+    Parameters
+    ----------
+    data : pd.DataFrame
+        The dataframe containing spectrum information such as 'mz_values', 'intensity_values', 'ions'.
+    title : str
+        The title of the plot.
+    sequence: str
+        The peptide sequence.
+    predicted : tuple
+        The tuple containing values of the predicted FragmentMz, RelativeIntensity and ions in the form of:
+        (predicted_df.FragmentMz, predicted_df.RelativeIntensity, predicted_df.ions). Default: empty tuple.
+    spectrum_color : str
+        The color of the mass spectrum. Default is 'grey'.
+    b_ion_color : str
+        The color of the b-ions. Default is 'red'.
+    y_ion_color : str
+        The color of the y-ions. Default is 'blue'.
+    spectrum_line_width: float
+        The width of the spectrum peaks. Default is 1.5.
+    font_size_seq: int
+        The font size of the peptide sequence letters. Default is 14.
+    font_size_ion: int
+        The font size of the ion letters. Default is 10.
+    height: int
+        The height of the plot. Default is 520.
+
+    Returns
+    -------
+    plotly.graph_objects.Figure object
+        The ms2 spectum plot with the mass error plot for each ion and the annotated peptide sequence as subplots.
+
+    """
+    fig = plot_mass_spectra(data=data, title=title, predicted=predicted, spectrum_color=spectrum_color, template=template, b_ion_color=b_ion_color, y_ion_color=y_ion_color, spectrum_line_width=spectrum_line_width, height=height)
 
     fig_common = plotly.subplots.make_subplots(
         rows=6, cols=3, shared_xaxes=True,
@@ -622,6 +715,7 @@ def plot_mass_spectra(
     )
 
     # add a second plot
+    data_b_ions = data[data.ions.str.contains('b')]
     fig_common.add_trace(
         go.Scatter(
             x=data_b_ions.mz_values,
@@ -637,6 +731,7 @@ def plot_mass_spectra(
         ),
         row=4, col=1
     )
+    data_y_ions = data[data.ions.str.contains('y')]
     fig_common.add_trace(
         go.Scatter(
             x=data_y_ions.mz_values,
@@ -662,7 +757,7 @@ def plot_mass_spectra(
 
     sl = len(sequence)
     distance_from_side = (data.mz_values.max() - data.mz_values.min()) * 2/8
-    distance = np.linspace(data.mz_values.min()+distance_from_side, data.mz_values.max()-distance_from_side, sl)
+    distance = np.linspace(data.mz_values.min()+distance_from_side, data.mz_values.max()-distance_from_side, sl+1)
     for i, aa in enumerate(sequence):
         fig_common.add_annotation(
             dict(
@@ -680,8 +775,8 @@ def plot_mass_spectra(
         if b:
             fig_common.add_trace(
                 go.Scatter(
-                    x=[distance[i],distance[i] + (distance[i+1] - distance[i])/2,distance[i] + (distance[i+1] - distance[i])/2],
-                    y=[0.7,0.7,0],
+                    x=[distance[i], distance[i] + (distance[i+1] - distance[i])/2, distance[i] + (distance[i+1] - distance[i])/2],
+                    y=[0.7, 0.7, 0],
                     mode="lines",
                     showlegend=False,
                     marker_color=b_ion_color,
@@ -706,8 +801,8 @@ def plot_mass_spectra(
         if y:
             fig_common.add_trace(
                 go.Scatter(
-                    x=[distance[i],distance[i] - (distance[i+1] - distance[i])/2,distance[i] - (distance[i+1] - distance[i])/2],
-                    y=[-0.7,-0.7,0],
+                    x=[distance[i], distance[i] - (distance[i+1] - distance[i])/2, distance[i] - (distance[i+1] - distance[i])/2],
+                    y=[-0.7, -0.7, 0],
                     mode="lines",
                     showlegend=False,
                     marker_color=y_ion_color,
@@ -730,7 +825,7 @@ def plot_mass_spectra(
             )
     fig_common.update_yaxes(
         visible=False,
-        range=(-1.1,1.1),
+        range=(-1.1, 1.1),
         row=6,
         col=1
     )
@@ -740,7 +835,7 @@ def plot_mass_spectra(
         col=1
     )
     fig_common.update_xaxes(matches='x')
-    return fig_common # this function is quite long. Can it be split in smaller chunks?
+    return fig_common
 
 
 def plot_mass_error(
@@ -749,7 +844,7 @@ def plot_mass_error(
     y_axis_label: str,
     plot_title: str,
     mz_tol: float = None
-)-> go.Figure:
+) -> go.Figure:
     """Create a density plot superimposed on the scatter plot together with the 1D distributions of both variables as marginal histograms.
 
     Parameters
@@ -772,109 +867,64 @@ def plot_mass_error(
     fig = go.Figure()
     fig.add_trace(
         go.Histogram2dContour(
-            x = df[x_axis_label].values,
-            y = df[y_axis_label].values,
-            colorscale = 'Blues',
-            ncontours = 6,
-            xaxis = 'x',
-            yaxis = 'y',
+            x=df[x_axis_label].values,
+            y=df[y_axis_label].values,
+            colorscale='Blues',
+            ncontours=5,
             name=" ",
-            contours = dict(
-                showlabels = False,
-                coloring = 'fill'
+            contours=dict(
+                showlabels=False,
+                coloring='fill'
             ),
+            hoverinfo='none',
         )
     )
     fig.add_trace(
         go.Scatter(
-            x = df[x_axis_label].values,
-            y = df[y_axis_label].values,
-            xaxis = 'x',
-            yaxis = 'y',
-            mode = 'markers',
-            marker = dict(
-                color = 'rgba(0,0,0,0.3)',
-                size = 3,
-                opacity = 0.2
+            x=df[x_axis_label].values,
+            y=df[y_axis_label].values,
+            mode='markers',
+            marker=dict(
+                color='rgba(0,0,0,0.3)',
+                size=3,
+                opacity=0.2
             ),
-            name=" "
-        )
-    )
-    fig.add_trace(
-        go.Histogram(
-            y = df[y_axis_label].values,
-            xaxis = 'x2',
-            nbinsy=50,
-            marker = dict(
-                color = 'rgb(198,219,239)'
-            )
-        )
-    )
-    fig.add_trace(
-        go.Histogram(
-            x = df[x_axis_label].values,
-            yaxis = 'y2',
-            nbinsx=50,
-            marker = dict(
-                color = 'rgb(198,219,239)'
-            )
+            name=" ",
+            # hoverinfo='none',
         )
     )
     if mz_tol:
         fig.add_trace(
             go.Scatter(
-                x = [df[x_axis_label].values.min(), df[x_axis_label].values.max()],
-                y = [mz_tol, mz_tol],
+                x=[df[x_axis_label].values.min(), df[x_axis_label].values.max()],
+                y=[mz_tol, mz_tol],
                 mode='lines',
                 line=dict(
                     color='darkred',
                     width=2,
                     dash='dash'
                 ),
-                showlegend = False,
+                showlegend=False,
                 hoverinfo='none',
             )
         )
         fig.add_trace(
             go.Scatter(
-                x = [df[x_axis_label].values.min(), df[x_axis_label].values.max()],
-                y = [-mz_tol, -mz_tol],
+                x=[df[x_axis_label].values.min(), df[x_axis_label].values.max()],
+                y=[-mz_tol, -mz_tol],
                 mode='lines',
                 line=dict(
                     color='darkred',
                     width=2,
                     dash='dash'
                 ),
-                showlegend = False,
+                showlegend=False,
                 hoverinfo='none',
             )
         )
 
     fig.update_layout(
-        autosize = False,
-        xaxis = dict(
-            zeroline = True,
-            domain = [0,0.85],
-            showgrid = True,
-            title=x_axis_label,
-
-        ),
-        yaxis = dict(
-            zeroline = True,
-            domain = [0,0.85],
-            showgrid = True,
-            title=y_axis_label,
-        ),
-        xaxis2 = dict(
-            zeroline = True,
-            domain = [0.85,1],
-            showgrid = True
-        ),
-        yaxis2 = dict(
-            zeroline = True,
-            domain = [0.85,1],
-            showgrid = True
-        ),
+        autosize=False,
         title=dict(
             text=plot_title,
             font=dict(
@@ -884,20 +934,21 @@ def plot_mass_error(
             xanchor='center',
             yanchor='top'
         ),
-        height = 600,
-        width = 600,
-        bargap = 0,
-        hovermode = 'closest',
-        showlegend = False,
-        template = "plotly_white"
+        height=500,
+        width=500,
+        bargap=0,
+        hovermode='closest',
+        showlegend=False,
+        template='plotly_white'
     )
     return fig
 
+
 def plot_peptide_distr(
     df: pd.DataFrame,
     x_axis_label: str,
     plot_title: str
-)-> go.Figure:
+) -> go.Figure:
     """Create a distribution plot in conjuction with boxplot.
 
     Parameters
@@ -919,23 +970,23 @@ def plot_peptide_distr(
 
     fig.add_trace(
         go.Histogram(
-            x = df[x_axis_label],
-            xaxis = 'x',
+            x=df[x_axis_label],
+            xaxis='x',
             nbinsy=50,
-            marker = dict(
-                color = 'rgb(198,219,239)'
+            marker=dict(
+                color='rgb(198,219,239)'
             ),
-            showlegend = False,
+            showlegend=False,
         )
     )
 
     fig.add_trace(
         go.Box(
             x=df[x_axis_label],
-            yaxis = 'y2',
+            yaxis='y2',
             marker_color='rgb(198,219,239)',
             name='',
-            showlegend = False,
+            showlegend=False,
         )
     )
 
@@ -949,30 +1000,30 @@ def plot_peptide_distr(
             xanchor='center',
             yanchor='top'
         ),
-        xaxis = dict(
-            zeroline = True,
-            domain = [0,0.85],
-            showgrid = True,
+        xaxis=dict(
+            zeroline=True,
+            domain=[0, 0.85],
+            showgrid=True,
             title=x_axis_label,
 
         ),
-        yaxis = dict(
-            zeroline = True,
-            domain = [0,0.85],
-            showgrid = True,
+        yaxis=dict(
+            zeroline=True,
+            domain=[0, 0.85],
+            showgrid=True,
             title='Count',
         ),
-        yaxis2 = dict(
-            zeroline = True,
-            domain = [0.85,1],
-            showgrid = True,
+        yaxis2=dict(
+            zeroline=True,
+            domain=[0.85, 1],
+            showgrid=True,
             title=''
         ),
         bargroupgap=0.1,
-        template = "plotly_white",
-        showlegend = False,
-        height = 400,
-        width = 600,
+        template='plotly_white',
+        showlegend=False,
+        height=400,
+        width=600,
     )
     return fig
 
@@ -1023,7 +1074,7 @@ def plot_elution_heatmap(
 
     df["rt_values"] /= 60
 
-    opts_ms1=dict(
+    opts_ms1 = dict(
         width=width,
         height=height,
         title=title,
@@ -1057,6 +1108,7 @@ def plot_elution_heatmap(
 
     return fig
 
+
 def plot_elution_profile_heatmap(
     timstof_data,
     peptide_info: dict,
@@ -1110,7 +1162,7 @@ def plot_elution_profile_heatmap(
         mass_dict=mass_dict
     )
     peptide_info['fragments'] = {
-        (f"b{key}" if key>0 else f"y{-key}"):value for key,value in zip(frag_type, frag_masses)
+        (f"b{key}" if key > 0 else f"y{-key}"): value for key, value in zip(frag_type, frag_masses)
     }
 
     # slice the data using the rt_tol, im_tol and mz_tol values
@@ -1162,8 +1214,11 @@ def plot_elution_profile_heatmap(
                 # ylim=(im_slice.start, im_slice.stop),
                 **kwargs
             )
+    try:
+        return common_plot.cols(n_cols)
+    except AttibuteError:
+        return common_plot
 
-    return common_plot.cols(n_cols)
 
 def plot_elution_line(
     timstof_data,
@@ -1198,7 +1253,7 @@ def plot_elution_line(
         "intensity": "Intensity",
     }
     x_axis_label = axis_dict["rt"]
-    y_axis_label = axis_dict["intensity"]
+    # y_axis_label = axis_dict["intensity"]
     labels = {
         'RT, min': "rt_values",
     }
@@ -1224,13 +1279,14 @@ def plot_elution_line(
         x=x_ticks,
         y=intensities,
         mode='lines',
-        text = [f'{x_axis_label}'.format(i + 1) for i in range(len(x_ticks))],
+        text=[f'{x_axis_label}'.format(i + 1) for i in range(len(x_ticks))],
         hovertemplate='<b>%{text}:</b> %{x};<br><b>Intensity:</b> %{y}.',
         name=label,
         marker=marker_color,
     )
     return trace
 
+
 def plot_elution_profile(
     raw_data,
     peptide_info: dict,
@@ -1283,7 +1339,7 @@ def plot_elution_profile(
         mass_dict=mass_dict
     )
     peptide_info['fragments'] = {
-        (f"b{key}" if key>0 else f"y{-key}"):value for key,value in zip(frag_type, frag_masses)
+        (f"b{key}" if key > 0 else f"y{-key}"): value for key, value in zip(frag_type, frag_masses)
     }
 
     # slice the data using the rt_tol, im_tol and mz_tol values
@@ -1348,23 +1404,28 @@ def plot_elution_profile(
         xaxis=dict(
             title=x_axis_label,
             titlefont_size=14,
-            tickmode = 'auto',
+            tickmode='auto',
             tickfont_size=14,
         ),
         yaxis=dict(
             title=y_axis_label
         ),
         legend=dict(
-            orientation="h",
-            yanchor="bottom",
-            y=-0.6,
-            xanchor="right",
-            x=0.95
+            orientation='h',
+            yanchor='bottom',
+            y=-1,
+            xanchor='right',
+            x=0.95,
+            font=dict(
+                # family="Courier",
+                size=11,
+                color='black'
+            ),
         ),
-        template = "plotly_white",
+        template='plotly_white',
         # width=width,
         height=height,
-        hovermode="x unified",
+        hovermode='x unified',
         showlegend=True
     )
     return fig
@@ -1374,7 +1435,7 @@ def plot_pept_per_protein_barplot(
     df: pd.DataFrame,
     x_axis_label: str,
     plot_title: str
-)-> go.Figure:
+) -> go.Figure:
     """Create a barplot for the number of peptides identified per protein.
 
     Parameters
@@ -1393,7 +1454,7 @@ def plot_pept_per_protein_barplot(
 
     """
     df = df.copy()
-    df['pept_per_prot'] = df[x_axis_label].apply(lambda x: str(x) if x <5 else '>5')
+    df['pept_per_prot'] = df[x_axis_label].apply(lambda x: str(x) if x < 5 else '>5')
 
     fig = go.Figure()
 
@@ -1406,8 +1467,8 @@ def plot_pept_per_protein_barplot(
             ),
             text=[f'{each:.2f}' for each in df.pept_per_prot.value_counts(normalize=True).sort_index().values],
             textfont={
-                'size':8,
-                'color':'green'
+                'size': 8,
+                'color': 'green'
             },
         )
     )
@@ -1422,19 +1483,25 @@ def plot_pept_per_protein_barplot(
             xanchor='center',
             yanchor='top'
         ),
-        xaxis = dict(
-            zeroline = True,
-            showgrid = True,
-            title="Number of peptide",
+        xaxis=dict(
+            zeroline=True,
+            showgrid=True,
+            title='Number of peptide',
 
         ),
-        yaxis = dict(
-            zeroline = True,
-            showgrid = True,
+        yaxis=dict(
+            zeroline=True,
+            showgrid=True,
             title='Count',
         ),
-        template = "plotly_white",
-        height = 400,
-        width = 400,
+        template='plotly_white',
+        height=400,
+        width=400,
     )
     return fig
+
+
+def export_svg(obj, filename='test', width=500, height=500):
+    plot_state = hv.renderer('bokeh').get_plot(obj).state
+    plot_state.output_backend = 'svg'
+    export_svgs(plot_state, filename=filename, width=width, height=height)
